# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmwasm/wasm/v1/proposal.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmwasm/wasm/v1/proposal.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmwasm/wasm/v1/proposal.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\"\xbd\x01\n\x11StoreCodeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12(\n\x0ewasm_byte_code\x18\x04 \x01(\x0c\x42\x10\xe2\xde\x1f\x0cWASMByteCode\x12>\n\x16instantiate_permission\x18\x07 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x8d\x02\n\x1bInstantiateContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12\r\n\x05\x61\x64min\x18\x04 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x05 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\r\n\x05label\x18\x06 \x01(\t\x12#\n\x03msg\x18\x07 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12Z\n\x05\x66unds\x18\x08 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\x91\x01\n\x17MigrateContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x04 \x01(\t\x12\x1b\n\x07\x63ode_id\x18\x05 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12#\n\x03msg\x18\x06 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"q\n\x14SudoContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t\x12#\n\x03msg\x18\x04 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"\xe0\x01\n\x17\x45xecuteContractProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06run_as\x18\x03 \x01(\t\x12\x10\n\x08\x63ontract\x18\x04 \x01(\t\x12#\n\x03msg\x18\x05 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\x12Z\n\x05\x66unds\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"t\n\x13UpdateAdminProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\'\n\tnew_admin\x18\x03 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"new_admin\"\x12\x10\n\x08\x63ontract\x18\x04 \x01(\t\"J\n\x12\x43learAdminProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x63ontract\x18\x03 \x01(\t\"\x92\x01\n\x10PinCodesProposal\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12\x30\n\x08\x63ode_ids\x18\x03 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\"\"\x94\x01\n\x12UnpinCodesProposal\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12\x30\n\x08\x63ode_ids\x18\x03 \x03(\x04\x42\x1e\xe2\xde\x1f\x07\x43odeIDs\xf2\xde\x1f\x0fyaml:\"code_ids\"\"w\n\x12\x41\x63\x63\x65ssConfigUpdate\x12\x1b\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\n\xe2\xde\x1f\x06\x43odeID\x12\x44\n\x16instantiate_permission\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\x04\xc8\xde\x1f\x00\"\xba\x01\n\x1fUpdateInstantiateConfigProposal\x12\x1f\n\x05title\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"title\"\x12+\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x16\xf2\xde\x1f\x12yaml:\"description\"\x12I\n\x15\x61\x63\x63\x65ss_config_updates\x18\x03 \x03(\x0b\x32$.cosmwasm.wasm.v1.AccessConfigUpdateB\x04\xc8\xde\x1f\x00\x42\x34Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xd8\xe1\x1e\x00\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmwasm.wasm.v1.proposal_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\330\341\036\000\250\342\036\001'
  _globals['_STORECODEPROPOSAL'].fields_by_name['wasm_byte_code']._loaded_options = None
  _globals['_STORECODEPROPOSAL'].fields_by_name['wasm_byte_code']._serialized_options = b'\342\336\037\014WASMByteCode'
  _globals['_INSTANTIATECONTRACTPROPOSAL'].fields_by_name['code_id']._loaded_options = None
  _globals['_INSTANTIATECONTRACTPROPOSAL'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_INSTANTIATECONTRACTPROPOSAL'].fields_by_name['msg']._loaded_options = None
  _globals['_INSTANTIATECONTRACTPROPOSAL'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_INSTANTIATECONTRACTPROPOSAL'].fields_by_name['funds']._loaded_options = None
  _globals['_INSTANTIATECONTRACTPROPOSAL'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_MIGRATECONTRACTPROPOSAL'].fields_by_name['code_id']._loaded_options = None
  _globals['_MIGRATECONTRACTPROPOSAL'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_MIGRATECONTRACTPROPOSAL'].fields_by_name['msg']._loaded_options = None
  _globals['_MIGRATECONTRACTPROPOSAL'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_SUDOCONTRACTPROPOSAL'].fields_by_name['msg']._loaded_options = None
  _globals['_SUDOCONTRACTPROPOSAL'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_EXECUTECONTRACTPROPOSAL'].fields_by_name['msg']._loaded_options = None
  _globals['_EXECUTECONTRACTPROPOSAL'].fields_by_name['msg']._serialized_options = b'\372\336\037\022RawContractMessage'
  _globals['_EXECUTECONTRACTPROPOSAL'].fields_by_name['funds']._loaded_options = None
  _globals['_EXECUTECONTRACTPROPOSAL'].fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_UPDATEADMINPROPOSAL'].fields_by_name['new_admin']._loaded_options = None
  _globals['_UPDATEADMINPROPOSAL'].fields_by_name['new_admin']._serialized_options = b'\362\336\037\020yaml:\"new_admin\"'
  _globals['_PINCODESPROPOSAL'].fields_by_name['title']._loaded_options = None
  _globals['_PINCODESPROPOSAL'].fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _globals['_PINCODESPROPOSAL'].fields_by_name['description']._loaded_options = None
  _globals['_PINCODESPROPOSAL'].fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _globals['_PINCODESPROPOSAL'].fields_by_name['code_ids']._loaded_options = None
  _globals['_PINCODESPROPOSAL'].fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _globals['_UNPINCODESPROPOSAL'].fields_by_name['title']._loaded_options = None
  _globals['_UNPINCODESPROPOSAL'].fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _globals['_UNPINCODESPROPOSAL'].fields_by_name['description']._loaded_options = None
  _globals['_UNPINCODESPROPOSAL'].fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _globals['_UNPINCODESPROPOSAL'].fields_by_name['code_ids']._loaded_options = None
  _globals['_UNPINCODESPROPOSAL'].fields_by_name['code_ids']._serialized_options = b'\342\336\037\007CodeIDs\362\336\037\017yaml:\"code_ids\"'
  _globals['_ACCESSCONFIGUPDATE'].fields_by_name['code_id']._loaded_options = None
  _globals['_ACCESSCONFIGUPDATE'].fields_by_name['code_id']._serialized_options = b'\342\336\037\006CodeID'
  _globals['_ACCESSCONFIGUPDATE'].fields_by_name['instantiate_permission']._loaded_options = None
  _globals['_ACCESSCONFIGUPDATE'].fields_by_name['instantiate_permission']._serialized_options = b'\310\336\037\000'
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL'].fields_by_name['title']._serialized_options = b'\362\336\037\014yaml:\"title\"'
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL'].fields_by_name['description']._serialized_options = b'\362\336\037\022yaml:\"description\"'
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL'].fields_by_name['access_config_updates']._loaded_options = None
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL'].fields_by_name['access_config_updates']._serialized_options = b'\310\336\037\000'
  _globals['_STORECODEPROPOSAL']._serialized_start=138
  _globals['_STORECODEPROPOSAL']._serialized_end=327
  _globals['_INSTANTIATECONTRACTPROPOSAL']._serialized_start=330
  _globals['_INSTANTIATECONTRACTPROPOSAL']._serialized_end=599
  _globals['_MIGRATECONTRACTPROPOSAL']._serialized_start=602
  _globals['_MIGRATECONTRACTPROPOSAL']._serialized_end=747
  _globals['_SUDOCONTRACTPROPOSAL']._serialized_start=749
  _globals['_SUDOCONTRACTPROPOSAL']._serialized_end=862
  _globals['_EXECUTECONTRACTPROPOSAL']._serialized_start=865
  _globals['_EXECUTECONTRACTPROPOSAL']._serialized_end=1089
  _globals['_UPDATEADMINPROPOSAL']._serialized_start=1091
  _globals['_UPDATEADMINPROPOSAL']._serialized_end=1207
  _globals['_CLEARADMINPROPOSAL']._serialized_start=1209
  _globals['_CLEARADMINPROPOSAL']._serialized_end=1283
  _globals['_PINCODESPROPOSAL']._serialized_start=1286
  _globals['_PINCODESPROPOSAL']._serialized_end=1432
  _globals['_UNPINCODESPROPOSAL']._serialized_start=1435
  _globals['_UNPINCODESPROPOSAL']._serialized_end=1583
  _globals['_ACCESSCONFIGUPDATE']._serialized_start=1585
  _globals['_ACCESSCONFIGUPDATE']._serialized_end=1704
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL']._serialized_start=1707
  _globals['_UPDATEINSTANTIATECONFIGPROPOSAL']._serialized_end=1893
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cometbft/state/v1/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cometbft/state/v1/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cometbft.abci.v1 import types_pb2 as cometbft_dot_abci_dot_v1_dot_types__pb2
from cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2
from cometbft.types.v1 import types_pb2 as cometbft_dot_types_dot_v1_dot_types__pb2
from cometbft.types.v1 import validator_pb2 as cometbft_dot_types_dot_v1_dot_validator__pb2
from cometbft.version.v1 import types_pb2 as cometbft_dot_version_dot_v1_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63ometbft/state/v1/types.proto\x12\x11\x63ometbft.state.v1\x1a\x1c\x63ometbft/abci/v1/types.proto\x1a\x1e\x63ometbft/types/v1/params.proto\x1a\x1d\x63ometbft/types/v1/types.proto\x1a!cometbft/types/v1/validator.proto\x1a\x1f\x63ometbft/version/v1/types.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xbe\x01\n\x13LegacyABCIResponses\x12\x33\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32\x1e.cometbft.abci.v1.ExecTxResult\x12\x36\n\tend_block\x18\x02 \x01(\x0b\x32#.cometbft.state.v1.ResponseEndBlock\x12:\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32%.cometbft.state.v1.ResponseBeginBlock\"W\n\x12ResponseBeginBlock\x12\x41\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"\xde\x01\n\x10ResponseEndBlock\x12\x42\n\x11validator_updates\x18\x01 \x03(\x0b\x32!.cometbft.abci.v1.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x43\n\x17\x63onsensus_param_updates\x18\x02 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParams\x12\x41\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x17.cometbft.abci.v1.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10\x65vents,omitempty\"e\n\x0eValidatorsInfo\x12\x36\n\rvalidator_set\x18\x01 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"v\n\x13\x43onsensusParamsInfo\x12\x42\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"\xab\x01\n\x11\x41\x42\x43IResponsesInfo\x12\x45\n\x15legacy_abci_responses\x18\x01 \x01(\x0b\x32&.cometbft.state.v1.LegacyABCIResponses\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12?\n\x0e\x66inalize_block\x18\x03 \x01(\x0b\x32\'.cometbft.abci.v1.FinalizeBlockResponse\"T\n\x07Version\x12\x37\n\tconsensus\x18\x01 \x01(\x0b\x32\x1e.cometbft.version.v1.ConsensusB\x04\xc8\xde\x1f\x00\x12\x10\n\x08software\x18\x02 \x01(\t\"\xc2\x05\n\x05State\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1a.cometbft.state.v1.VersionB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x16\n\x0einitial_height\x18\x0e \x01(\x03\x12\x19\n\x11last_block_height\x18\x03 \x01(\x03\x12\x46\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x1a.cometbft.types.v1.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID\x12=\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x38\n\x0fnext_validators\x18\x06 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12\x33\n\nvalidators\x18\x07 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12\x38\n\x0flast_validators\x18\x08 \x01(\x0b\x32\x1f.cometbft.types.v1.ValidatorSet\x12&\n\x1elast_height_validators_changed\x18\t \x01(\x03\x12\x42\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32\".cometbft.types.v1.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12,\n$last_height_consensus_params_changed\x18\x0b \x01(\x03\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\r \x01(\x0c\x12=\n\x10next_block_delay\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x42\x34Z2github.com/cometbft/cometbft/api/cometbft/state/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.state.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z2github.com/cometbft/cometbft/api/cometbft/state/v1'
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEBEGINBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['validator_updates']._serialized_options = b'\310\336\037\000'
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._loaded_options = None
  _globals['_RESPONSEENDBLOCK'].fields_by_name['events']._serialized_options = b'\310\336\037\000\352\336\037\020events,omitempty'
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_CONSENSUSPARAMSINFO'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_VERSION'].fields_by_name['consensus']._loaded_options = None
  _globals['_VERSION'].fields_by_name['consensus']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['version']._loaded_options = None
  _globals['_STATE'].fields_by_name['version']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['chain_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['chain_id']._serialized_options = b'\342\336\037\007ChainID'
  _globals['_STATE'].fields_by_name['last_block_id']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_id']._serialized_options = b'\310\336\037\000\342\336\037\013LastBlockID'
  _globals['_STATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_STATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_STATE'].fields_by_name['consensus_params']._loaded_options = None
  _globals['_STATE'].fields_by_name['consensus_params']._serialized_options = b'\310\336\037\000'
  _globals['_STATE'].fields_by_name['next_block_delay']._loaded_options = None
  _globals['_STATE'].fields_by_name['next_block_delay']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_LEGACYABCIRESPONSES']._serialized_start=301
  _globals['_LEGACYABCIRESPONSES']._serialized_end=491
  _globals['_RESPONSEBEGINBLOCK']._serialized_start=493
  _globals['_RESPONSEBEGINBLOCK']._serialized_end=580
  _globals['_RESPONSEENDBLOCK']._serialized_start=583
  _globals['_RESPONSEENDBLOCK']._serialized_end=805
  _globals['_VALIDATORSINFO']._serialized_start=807
  _globals['_VALIDATORSINFO']._serialized_end=908
  _globals['_CONSENSUSPARAMSINFO']._serialized_start=910
  _globals['_CONSENSUSPARAMSINFO']._serialized_end=1028
  _globals['_ABCIRESPONSESINFO']._serialized_start=1031
  _globals['_ABCIRESPONSESINFO']._serialized_end=1202
  _globals['_VERSION']._serialized_start=1204
  _globals['_VERSION']._serialized_end=1288
  _globals['_STATE']._serialized_start=1291
  _globals['_STATE']._serialized_end=1997
# @@protoc_insertion_point(module_scope)



from neurionpy.protos.neurion.sanctum.tx_pb2 import (
    MsgSubmitDatasetApplication, MsgSubmitDatasetApplicationResponse,
    MsgApproveApplication, MsgApproveApplicationResponse,
    MsgRejectApplication, MsgRejectApplicationResponse,
    MsgDisclaimDataset, MsgDisclaimDatasetResponse,
    MsgRequestToUseDataset, MsgRequestToUseDatasetResponse,
    MsgCancelDatasetUsageRequest, MsgCancelDatasetUsageRequestResponse,
    MsgRejectDatasetUsageRequest, MsgRejectDatasetUsageRequestResponse,
    MsgApproveDatasetUsageRequest, MsgApproveDatasetUsageRequestResponse,
    MsgAddProcessor, MsgAddProcessorResponse,
    MsgRemoveProcessor, MsgRemoveProcessorResponse,
    MsgProcessDatasetUsageRequest, MsgProcessDatasetUsageRequestResponse,
    MsgFinishDatasetUsageRequest, MsgFinishDatasetUsageRequestResponse,
    MsgDisputeDatasetUsageRequest, MsgDisputeDatasetUsageRequestResponse,
    MsgApproveDispute, MsgApproveDisputeResponse,
    MsgRejectDispute, MsgRejectDisputeResponse,
    MsgStakeToSanctum, MsgStakeToSanctumResponse,
    MsgUnstakeFromSanctum, MsgUnstakeFromSanctumResponse,
    MsgClaimReward, MsgClaimRewardResponse,
)

from neurionpy.synapse.tx_helpers import SubmittedTx

from abc import ABC, abstractmethod
from typing import Optional

from neurionpy.protos.neurion.sanctum.query_pb2 import (
    QueryParamsRequest, QueryParamsResponse,
    QueryGetAvailableDatasetsRequest, QueryGetAvailableDatasetsResponse,
    QueryGetApprovedUsageRequestsRequest, QueryGetApprovedUsageRequestsResponse,
    QueryGetRewardRequest, QueryGetRewardResponse,
    QueryGetStakeRequest, QueryGetStakeResponse,
    QueryGetPendingDatasetsRequest, QueryGetPendingDatasetsResponse,
    QueryGetPendingUsageRequestsRequest, QueryGetPendingUsageRequestsResponse,
    QueryGetDatasetRequest, QueryGetDatasetResponse,
    QueryGetUsageRequestRequest, QueryGetUsageRequestResponse,
    QueryGetUsageRequestsForDatasetRequest, QueryGetUsageRequestsForDatasetResponse,
    QueryGetUsageRequestsForUserRequest, QueryGetUsageRequestsForUserResponse,
    QueryGetDatasetsForUserRequest, QueryGetDatasetsForUserResponse,
)


class SanctumQuery(ABC):
    """Sanctum abstract class defining query methods."""

    @abstractmethod
    def Params(self, request: QueryParamsRequest) -> QueryParamsResponse:
        """Query module parameters."""

    @abstractmethod
    def GetAvailableDatasets(self, request: QueryGetAvailableDatasetsRequest) -> QueryGetAvailableDatasetsResponse:
        """Query available datasets with pagination."""

    @abstractmethod
    def GetApprovedUsageRequests(self, request: QueryGetApprovedUsageRequestsRequest) -> QueryGetApprovedUsageRequestsResponse:
        """Query approved dataset usage requests."""

    @abstractmethod
    def GetReward(self, request: QueryGetRewardRequest) -> QueryGetRewardResponse:
        """Query the reward for a user."""

    @abstractmethod
    def GetStake(self, request: QueryGetStakeRequest) -> QueryGetStakeResponse:
        """Query the stake for a user."""

    @abstractmethod
    def GetPendingDatasets(self, request: QueryGetPendingDatasetsRequest) -> QueryGetPendingDatasetsResponse:
        """Query pending dataset applications."""

    @abstractmethod
    def GetPendingUsageRequests(self, request: QueryGetPendingUsageRequestsRequest) -> QueryGetPendingUsageRequestsResponse:
        """Query pending usage requests for a user."""

    @abstractmethod
    def GetDataset(self, request: QueryGetDatasetRequest) -> QueryGetDatasetResponse:
        """Query details of a specific dataset."""

    @abstractmethod
    def GetUsageRequest(self, request: QueryGetUsageRequestRequest) -> QueryGetUsageRequestResponse:
        """Query details of a specific dataset usage request."""

    @abstractmethod
    def GetUsageRequestsForDataset(self, request: QueryGetUsageRequestsForDatasetRequest) -> QueryGetUsageRequestsForDatasetResponse:
        """Query usage requests for a specific dataset with pagination."""

    @abstractmethod
    def GetUsageRequestsForUser(self, request: QueryGetUsageRequestsForUserRequest) -> QueryGetUsageRequestsForUserResponse:
        """Query usage requests made by a user with pagination."""

    @abstractmethod
    def GetDatasetsForUser(self, request: QueryGetDatasetsForUserRequest) -> QueryGetDatasetsForUserResponse:
        """Query datasets owned by a user with pagination."""


class SanctumMessage(ABC):
    """Sanctum abstract class defining message methods."""

    @abstractmethod
    def SubmitDatasetApplication(self, message: MsgSubmitDatasetApplication,
                                 memo: Optional[str] = None,
                                 gas_limit: Optional[int] = None) -> SubmittedTx:
        """Submit a dataset application."""

    @abstractmethod
    def ApproveApplication(self, message: MsgApproveApplication,
                           memo: Optional[str] = None,
                           gas_limit: Optional[int] = None) -> SubmittedTx:
        """Approve a dataset application."""

    @abstractmethod
    def RejectApplication(self, message: MsgRejectApplication,
                          memo: Optional[str] = None,
                          gas_limit: Optional[int] = None) -> SubmittedTx:
        """Reject a dataset application."""

    @abstractmethod
    def DisclaimDataset(self, message: MsgDisclaimDataset,
                        memo: Optional[str] = None,
                        gas_limit: Optional[int] = None) -> SubmittedTx:
        """Disclaim a dataset."""

    @abstractmethod
    def RequestToUseDataset(self, message: MsgRequestToUseDataset,
                            memo: Optional[str] = None,
                            gas_limit: Optional[int] = None) -> SubmittedTx:
        """Request to use a dataset."""

    @abstractmethod
    def CancelDatasetUsageRequest(self, message: MsgCancelDatasetUsageRequest,
                                  memo: Optional[str] = None,
                                  gas_limit: Optional[int] = None) -> SubmittedTx:
        """Cancel a dataset usage request."""

    @abstractmethod
    def RejectDatasetUsageRequest(self, message: MsgRejectDatasetUsageRequest,
                                  memo: Optional[str] = None,
                                  gas_limit: Optional[int] = None) -> SubmittedTx:
        """Reject a dataset usage request."""

    @abstractmethod
    def ApproveDatasetUsageRequest(self, message: MsgApproveDatasetUsageRequest,
                                   memo: Optional[str] = None,
                                   gas_limit: Optional[int] = None) -> SubmittedTx:
        """Approve a dataset usage request."""

    @abstractmethod
    def AddProcessor(self, message: MsgAddProcessor,
                     memo: Optional[str] = None,
                     gas_limit: Optional[int] = None) -> SubmittedTx:
        """Add a processor."""

    @abstractmethod
    def RemoveProcessor(self, message: MsgRemoveProcessor,
                        memo: Optional[str] = None,
                        gas_limit: Optional[int] = None) -> SubmittedTx:
        """Remove a processor."""

    @abstractmethod
    def ProcessDatasetUsageRequest(self, message: MsgProcessDatasetUsageRequest,
                                   memo: Optional[str] = None,
                                   gas_limit: Optional[int] = None) -> SubmittedTx:
        """Process a dataset usage request."""

    @abstractmethod
    def FinishDatasetUsageRequest(self, message: MsgFinishDatasetUsageRequest,
                                  memo: Optional[str] = None,
                                  gas_limit: Optional[int] = None) -> SubmittedTx:
        """Finish a dataset usage request."""

    @abstractmethod
    def DisputeDatasetUsageRequest(self, message: MsgDisputeDatasetUsageRequest,
                                   memo: Optional[str] = None,
                                   gas_limit: Optional[int] = None) -> SubmittedTx:
        """Dispute a dataset usage request."""

    @abstractmethod
    def ApproveDispute(self, message: MsgApproveDispute,
                       memo: Optional[str] = None,
                       gas_limit: Optional[int] = None) -> SubmittedTx:
        """Approve a dispute."""

    @abstractmethod
    def RejectDispute(self, message: MsgRejectDispute,
                      memo: Optional[str] = None,
                      gas_limit: Optional[int] = None) -> SubmittedTx:
        """Reject a dispute."""

    @abstractmethod
    def StakeToSanctum(self, message: MsgStakeToSanctum,
                       memo: Optional[str] = None,
                       gas_limit: Optional[int] = None) -> SubmittedTx:
        """Stake tokens to Sanctum."""

    @abstractmethod
    def UnstakeFromSanctum(self, message: MsgUnstakeFromSanctum,
                           memo: Optional[str] = None,
                           gas_limit: Optional[int] = None) -> SubmittedTx:
        """Unstake tokens from Sanctum."""

    @abstractmethod
    def ClaimReward(self, message: MsgClaimReward,
                    memo: Optional[str] = None,
                    gas_limit: Optional[int] = None) -> SubmittedTx:
        """Claim reward."""


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.fusion import query_pb2 as neurion_dot_fusion_dot_query__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/fusion/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/neurion.fusion.Query/Params',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.GetTask = channel.unary_unary(
                '/neurion.fusion.Query/GetTask',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskResponse.FromString,
                _registered_method=True)
        self.GetTaskReward = channel.unary_unary(
                '/neurion.fusion.Query/GetTaskReward',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskRewardRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskRewardResponse.FromString,
                _registered_method=True)
        self.GetCreatorApplications = channel.unary_unary(
                '/neurion.fusion.Query/GetCreatorApplications',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetCreatorApplicationsRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetCreatorApplicationsResponse.FromString,
                _registered_method=True)
        self.GetPendingCreatorApplications = channel.unary_unary(
                '/neurion.fusion.Query/GetPendingCreatorApplications',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingCreatorApplicationsRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingCreatorApplicationsResponse.FromString,
                _registered_method=True)
        self.GetModelsByRound = channel.unary_unary(
                '/neurion.fusion.Query/GetModelsByRound',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetModelsByRoundRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetModelsByRoundResponse.FromString,
                _registered_method=True)
        self.GetTaskStake = channel.unary_unary(
                '/neurion.fusion.Query/GetTaskStake',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskStakeRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskStakeResponse.FromString,
                _registered_method=True)
        self.GetValidationTask = channel.unary_unary(
                '/neurion.fusion.Query/GetValidationTask',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetValidationTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetValidationTaskResponse.FromString,
                _registered_method=True)
        self.CanTriggerTestingForRound = channel.unary_unary(
                '/neurion.fusion.Query/CanTriggerTestingForRound',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanTriggerTestingForRoundRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanTriggerTestingForRoundResponse.FromString,
                _registered_method=True)
        self.CanStartNewRound = channel.unary_unary(
                '/neurion.fusion.Query/CanStartNewRound',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanStartNewRoundRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanStartNewRoundResponse.FromString,
                _registered_method=True)
        self.CanRegisterAsProposer = channel.unary_unary(
                '/neurion.fusion.Query/CanRegisterAsProposer',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsProposerRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsProposerResponse.FromString,
                _registered_method=True)
        self.CanRegisterAsValidator = channel.unary_unary(
                '/neurion.fusion.Query/CanRegisterAsValidator',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsValidatorRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsValidatorResponse.FromString,
                _registered_method=True)
        self.IsProposer = channel.unary_unary(
                '/neurion.fusion.Query/IsProposer',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryIsProposerRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryIsProposerResponse.FromString,
                _registered_method=True)
        self.IsValidator = channel.unary_unary(
                '/neurion.fusion.Query/IsValidator',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryIsValidatorRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryIsValidatorResponse.FromString,
                _registered_method=True)
        self.CanProposeModel = channel.unary_unary(
                '/neurion.fusion.Query/CanProposeModel',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanProposeModelRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanProposeModelResponse.FromString,
                _registered_method=True)
        self.CanRequestValidationTask = channel.unary_unary(
                '/neurion.fusion.Query/CanRequestValidationTask',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanRequestValidationTaskRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanRequestValidationTaskResponse.FromString,
                _registered_method=True)
        self.GetPendingValidationTasks = channel.unary_unary(
                '/neurion.fusion.Query/GetPendingValidationTasks',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingValidationTasksRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingValidationTasksResponse.FromString,
                _registered_method=True)
        self.CanTerminate = channel.unary_unary(
                '/neurion.fusion.Query/CanTerminate',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanTerminateRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanTerminateResponse.FromString,
                _registered_method=True)
        self.GetScoreDisputeFromUser = channel.unary_unary(
                '/neurion.fusion.Query/GetScoreDisputeFromUser',
                request_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetScoreDisputeFromUserRequest.SerializeToString,
                response_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetScoreDisputeFromUserResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTask(self, request, context):
        """Queries a list of GetTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskReward(self, request, context):
        """Queries a list of GetTaskReward items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCreatorApplications(self, request, context):
        """Queries a list of GetCreatorApplications items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingCreatorApplications(self, request, context):
        """Queries a list of GetPendingCreatorApplications items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelsByRound(self, request, context):
        """Queries a list of GetModelsByRound items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTaskStake(self, request, context):
        """Queries a list of GetTaskStake items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidationTask(self, request, context):
        """Queries a list of GetValidationTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanTriggerTestingForRound(self, request, context):
        """Queries a list of CanTriggerTestingForRound items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanStartNewRound(self, request, context):
        """Queries a list of CanStartNewRound items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanRegisterAsProposer(self, request, context):
        """Queries a list of CanRegisterAsProposer items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanRegisterAsValidator(self, request, context):
        """Queries a list of CanRegisterAsValidator items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsProposer(self, request, context):
        """Queries a list of IsProposer items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsValidator(self, request, context):
        """Queries a list of IsValidator items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanProposeModel(self, request, context):
        """Queries a list of CanProposeModel items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanRequestValidationTask(self, request, context):
        """Queries a list of CanRequestValidationTask items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPendingValidationTasks(self, request, context):
        """Queries a list of GetPendingValidationTasks items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CanTerminate(self, request, context):
        """Queries a list of CanTerminate items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetScoreDisputeFromUser(self, request, context):
        """Queries a list of GetScoreDisputeFromUser items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'GetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTask,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskResponse.SerializeToString,
            ),
            'GetTaskReward': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskReward,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskRewardRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskRewardResponse.SerializeToString,
            ),
            'GetCreatorApplications': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCreatorApplications,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetCreatorApplicationsRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetCreatorApplicationsResponse.SerializeToString,
            ),
            'GetPendingCreatorApplications': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingCreatorApplications,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingCreatorApplicationsRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingCreatorApplicationsResponse.SerializeToString,
            ),
            'GetModelsByRound': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelsByRound,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetModelsByRoundRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetModelsByRoundResponse.SerializeToString,
            ),
            'GetTaskStake': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTaskStake,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskStakeRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetTaskStakeResponse.SerializeToString,
            ),
            'GetValidationTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidationTask,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetValidationTaskRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetValidationTaskResponse.SerializeToString,
            ),
            'CanTriggerTestingForRound': grpc.unary_unary_rpc_method_handler(
                    servicer.CanTriggerTestingForRound,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanTriggerTestingForRoundRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanTriggerTestingForRoundResponse.SerializeToString,
            ),
            'CanStartNewRound': grpc.unary_unary_rpc_method_handler(
                    servicer.CanStartNewRound,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanStartNewRoundRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanStartNewRoundResponse.SerializeToString,
            ),
            'CanRegisterAsProposer': grpc.unary_unary_rpc_method_handler(
                    servicer.CanRegisterAsProposer,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsProposerRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsProposerResponse.SerializeToString,
            ),
            'CanRegisterAsValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.CanRegisterAsValidator,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsValidatorRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsValidatorResponse.SerializeToString,
            ),
            'IsProposer': grpc.unary_unary_rpc_method_handler(
                    servicer.IsProposer,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryIsProposerRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryIsProposerResponse.SerializeToString,
            ),
            'IsValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.IsValidator,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryIsValidatorRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryIsValidatorResponse.SerializeToString,
            ),
            'CanProposeModel': grpc.unary_unary_rpc_method_handler(
                    servicer.CanProposeModel,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanProposeModelRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanProposeModelResponse.SerializeToString,
            ),
            'CanRequestValidationTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CanRequestValidationTask,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanRequestValidationTaskRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanRequestValidationTaskResponse.SerializeToString,
            ),
            'GetPendingValidationTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPendingValidationTasks,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingValidationTasksRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetPendingValidationTasksResponse.SerializeToString,
            ),
            'CanTerminate': grpc.unary_unary_rpc_method_handler(
                    servicer.CanTerminate,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryCanTerminateRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryCanTerminateResponse.SerializeToString,
            ),
            'GetScoreDisputeFromUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetScoreDisputeFromUser,
                    request_deserializer=neurion_dot_fusion_dot_query__pb2.QueryGetScoreDisputeFromUserRequest.FromString,
                    response_serializer=neurion_dot_fusion_dot_query__pb2.QueryGetScoreDisputeFromUserResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.fusion.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.fusion.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/Params',
            neurion_dot_fusion_dot_query__pb2.QueryParamsRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetTask',
            neurion_dot_fusion_dot_query__pb2.QueryGetTaskRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetTaskReward',
            neurion_dot_fusion_dot_query__pb2.QueryGetTaskRewardRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetTaskRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCreatorApplications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetCreatorApplications',
            neurion_dot_fusion_dot_query__pb2.QueryGetCreatorApplicationsRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetCreatorApplicationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingCreatorApplications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetPendingCreatorApplications',
            neurion_dot_fusion_dot_query__pb2.QueryGetPendingCreatorApplicationsRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetPendingCreatorApplicationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetModelsByRound(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetModelsByRound',
            neurion_dot_fusion_dot_query__pb2.QueryGetModelsByRoundRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetModelsByRoundResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTaskStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetTaskStake',
            neurion_dot_fusion_dot_query__pb2.QueryGetTaskStakeRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetTaskStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetValidationTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetValidationTask',
            neurion_dot_fusion_dot_query__pb2.QueryGetValidationTaskRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetValidationTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanTriggerTestingForRound(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanTriggerTestingForRound',
            neurion_dot_fusion_dot_query__pb2.QueryCanTriggerTestingForRoundRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanTriggerTestingForRoundResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanStartNewRound(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanStartNewRound',
            neurion_dot_fusion_dot_query__pb2.QueryCanStartNewRoundRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanStartNewRoundResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanRegisterAsProposer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanRegisterAsProposer',
            neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsProposerRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsProposerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanRegisterAsValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanRegisterAsValidator',
            neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsValidatorRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanRegisterAsValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsProposer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/IsProposer',
            neurion_dot_fusion_dot_query__pb2.QueryIsProposerRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryIsProposerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IsValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/IsValidator',
            neurion_dot_fusion_dot_query__pb2.QueryIsValidatorRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryIsValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanProposeModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanProposeModel',
            neurion_dot_fusion_dot_query__pb2.QueryCanProposeModelRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanProposeModelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanRequestValidationTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanRequestValidationTask',
            neurion_dot_fusion_dot_query__pb2.QueryCanRequestValidationTaskRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanRequestValidationTaskResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPendingValidationTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetPendingValidationTasks',
            neurion_dot_fusion_dot_query__pb2.QueryGetPendingValidationTasksRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetPendingValidationTasksResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CanTerminate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/CanTerminate',
            neurion_dot_fusion_dot_query__pb2.QueryCanTerminateRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryCanTerminateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetScoreDisputeFromUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.fusion.Query/GetScoreDisputeFromUser',
            neurion_dot_fusion_dot_query__pb2.QueryGetScoreDisputeFromUserRequest.SerializeToString,
            neurion_dot_fusion_dot_query__pb2.QueryGetScoreDisputeFromUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from neurion.ganglion import query_pb2 as neurion_dot_ganglion_dot_query__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in neurion/ganglion/query_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/neurion.ganglion.Query/Params',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.IonByIonAddress = channel.unary_unary(
                '/neurion.ganglion.Query/IonByIonAddress',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByIonAddressRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByIonAddressResponse.FromString,
                _registered_method=True)
        self.IonByCreator = channel.unary_unary(
                '/neurion.ganglion.Query/IonByCreator',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByCreatorRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByCreatorResponse.FromString,
                _registered_method=True)
        self.GetValidators = channel.unary_unary(
                '/neurion.ganglion.Query/GetValidators',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetValidatorsRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetValidatorsResponse.FromString,
                _registered_method=True)
        self.IonsByInputSchemaHash = channel.unary_unary(
                '/neurion.ganglion.Query/IonsByInputSchemaHash',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByInputSchemaHashRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByInputSchemaHashResponse.FromString,
                _registered_method=True)
        self.GetPathway = channel.unary_unary(
                '/neurion.ganglion.Query/GetPathway',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayResponse.FromString,
                _registered_method=True)
        self.ListPathways = channel.unary_unary(
                '/neurion.ganglion.Query/ListPathways',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryListPathwaysRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryListPathwaysResponse.FromString,
                _registered_method=True)
        self.ListIonsByAddresses = channel.unary_unary(
                '/neurion.ganglion.Query/ListIonsByAddresses',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryListIonsByAddressesRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryListIonsByAddressesResponse.FromString,
                _registered_method=True)
        self.UserPathwayStake = channel.unary_unary(
                '/neurion.ganglion.Query/UserPathwayStake',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryUserPathwayStakeRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryUserPathwayStakeResponse.FromString,
                _registered_method=True)
        self.GetUserReward = channel.unary_unary(
                '/neurion.ganglion.Query/GetUserReward',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetUserRewardRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetUserRewardResponse.FromString,
                _registered_method=True)
        self.GetProtocolFee = channel.unary_unary(
                '/neurion.ganglion.Query/GetProtocolFee',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetProtocolFeeRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetProtocolFeeResponse.FromString,
                _registered_method=True)
        self.PathwaysUsingIon = channel.unary_unary(
                '/neurion.ganglion.Query/PathwaysUsingIon',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryPathwaysUsingIonRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryPathwaysUsingIonResponse.FromString,
                _registered_method=True)
        self.IonsByReports = channel.unary_unary(
                '/neurion.ganglion.Query/IonsByReports',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByReportsRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByReportsResponse.FromString,
                _registered_method=True)
        self.ListAllPathways = channel.unary_unary(
                '/neurion.ganglion.Query/ListAllPathways',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryListAllPathwaysRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryListAllPathwaysResponse.FromString,
                _registered_method=True)
        self.GetReward = channel.unary_unary(
                '/neurion.ganglion.Query/GetReward',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetRewardRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetRewardResponse.FromString,
                _registered_method=True)
        self.GetStake = channel.unary_unary(
                '/neurion.ganglion.Query/GetStake',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakeRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakeResponse.FromString,
                _registered_method=True)
        self.GetIon = channel.unary_unary(
                '/neurion.ganglion.Query/GetIon',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetIonRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetIonResponse.FromString,
                _registered_method=True)
        self.GetPathwayUnstakeInitiatedUsers = channel.unary_unary(
                '/neurion.ganglion.Query/GetPathwayUnstakeInitiatedUsers',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayUnstakeInitiatedUsersRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayUnstakeInitiatedUsersResponse.FromString,
                _registered_method=True)
        self.GetStakerReward = channel.unary_unary(
                '/neurion.ganglion.Query/GetStakerReward',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakerRewardRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakerRewardResponse.FromString,
                _registered_method=True)
        self.GetAvailableIons = channel.unary_unary(
                '/neurion.ganglion.Query/GetAvailableIons',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAvailableIonsRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAvailableIonsResponse.FromString,
                _registered_method=True)
        self.ValidateIonChain = channel.unary_unary(
                '/neurion.ganglion.Query/ValidateIonChain',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryValidateIonChainRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryValidateIonChainResponse.FromString,
                _registered_method=True)
        self.GetAllowedIps = channel.unary_unary(
                '/neurion.ganglion.Query/GetAllowedIps',
                request_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAllowedIpsRequest.SerializeToString,
                response_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAllowedIpsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Parameters queries the parameters of the module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IonByIonAddress(self, request, context):
        """Queries a list of IonByIonAddress items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IonByCreator(self, request, context):
        """Queries a list of IonByCreator items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetValidators(self, request, context):
        """Queries a list of GetValidators items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IonsByInputSchemaHash(self, request, context):
        """Queries a list of IonsByInputSchemaHash items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPathway(self, request, context):
        """Queries a list of GetPathway items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPathways(self, request, context):
        """Queries a list of ListPathways items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIonsByAddresses(self, request, context):
        """Queries a list of ListIonsByAddresses items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserPathwayStake(self, request, context):
        """Queries a list of UserPathwayStake items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserReward(self, request, context):
        """Queries a list of GetUserReward items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProtocolFee(self, request, context):
        """Queries a list of GetProtocolFee items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PathwaysUsingIon(self, request, context):
        """Queries a list of PathwaysUsingIon items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IonsByReports(self, request, context):
        """Queries a list of IonsByReports items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllPathways(self, request, context):
        """Queries a list of ListAllPathways items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReward(self, request, context):
        """Queries a list of GetReward items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStake(self, request, context):
        """Queries a list of GetStake items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIon(self, request, context):
        """Queries a list of GetIon items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPathwayUnstakeInitiatedUsers(self, request, context):
        """Queries a list of GetPathwayUnstakeInitiatedUsers items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStakerReward(self, request, context):
        """Queries a list of GetStakerReward items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAvailableIons(self, request, context):
        """Queries a list of GetAvailableIons items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateIonChain(self, request, context):
        """Queries a list of ValidateIonChain items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllowedIps(self, request, context):
        """Queries a list of GetAllowedIps items.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'IonByIonAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.IonByIonAddress,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByIonAddressRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByIonAddressResponse.SerializeToString,
            ),
            'IonByCreator': grpc.unary_unary_rpc_method_handler(
                    servicer.IonByCreator,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByCreatorRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonByCreatorResponse.SerializeToString,
            ),
            'GetValidators': grpc.unary_unary_rpc_method_handler(
                    servicer.GetValidators,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetValidatorsRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetValidatorsResponse.SerializeToString,
            ),
            'IonsByInputSchemaHash': grpc.unary_unary_rpc_method_handler(
                    servicer.IonsByInputSchemaHash,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByInputSchemaHashRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByInputSchemaHashResponse.SerializeToString,
            ),
            'GetPathway': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPathway,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayResponse.SerializeToString,
            ),
            'ListPathways': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPathways,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryListPathwaysRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryListPathwaysResponse.SerializeToString,
            ),
            'ListIonsByAddresses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIonsByAddresses,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryListIonsByAddressesRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryListIonsByAddressesResponse.SerializeToString,
            ),
            'UserPathwayStake': grpc.unary_unary_rpc_method_handler(
                    servicer.UserPathwayStake,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryUserPathwayStakeRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryUserPathwayStakeResponse.SerializeToString,
            ),
            'GetUserReward': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserReward,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetUserRewardRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetUserRewardResponse.SerializeToString,
            ),
            'GetProtocolFee': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProtocolFee,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetProtocolFeeRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetProtocolFeeResponse.SerializeToString,
            ),
            'PathwaysUsingIon': grpc.unary_unary_rpc_method_handler(
                    servicer.PathwaysUsingIon,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryPathwaysUsingIonRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryPathwaysUsingIonResponse.SerializeToString,
            ),
            'IonsByReports': grpc.unary_unary_rpc_method_handler(
                    servicer.IonsByReports,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByReportsRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryIonsByReportsResponse.SerializeToString,
            ),
            'ListAllPathways': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllPathways,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryListAllPathwaysRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryListAllPathwaysResponse.SerializeToString,
            ),
            'GetReward': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReward,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetRewardRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetRewardResponse.SerializeToString,
            ),
            'GetStake': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStake,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakeRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakeResponse.SerializeToString,
            ),
            'GetIon': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIon,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetIonRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetIonResponse.SerializeToString,
            ),
            'GetPathwayUnstakeInitiatedUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPathwayUnstakeInitiatedUsers,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayUnstakeInitiatedUsersRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayUnstakeInitiatedUsersResponse.SerializeToString,
            ),
            'GetStakerReward': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStakerReward,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakerRewardRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetStakerRewardResponse.SerializeToString,
            ),
            'GetAvailableIons': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAvailableIons,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAvailableIonsRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAvailableIonsResponse.SerializeToString,
            ),
            'ValidateIonChain': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateIonChain,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryValidateIonChainRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryValidateIonChainResponse.SerializeToString,
            ),
            'GetAllowedIps': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllowedIps,
                    request_deserializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAllowedIpsRequest.FromString,
                    response_serializer=neurion_dot_ganglion_dot_query__pb2.QueryGetAllowedIpsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'neurion.ganglion.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('neurion.ganglion.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/Params',
            neurion_dot_ganglion_dot_query__pb2.QueryParamsRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IonByIonAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/IonByIonAddress',
            neurion_dot_ganglion_dot_query__pb2.QueryIonByIonAddressRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryIonByIonAddressResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IonByCreator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/IonByCreator',
            neurion_dot_ganglion_dot_query__pb2.QueryIonByCreatorRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryIonByCreatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetValidators(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetValidators',
            neurion_dot_ganglion_dot_query__pb2.QueryGetValidatorsRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetValidatorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IonsByInputSchemaHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/IonsByInputSchemaHash',
            neurion_dot_ganglion_dot_query__pb2.QueryIonsByInputSchemaHashRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryIonsByInputSchemaHashResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPathway(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetPathway',
            neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPathways(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/ListPathways',
            neurion_dot_ganglion_dot_query__pb2.QueryListPathwaysRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryListPathwaysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListIonsByAddresses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/ListIonsByAddresses',
            neurion_dot_ganglion_dot_query__pb2.QueryListIonsByAddressesRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryListIonsByAddressesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UserPathwayStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/UserPathwayStake',
            neurion_dot_ganglion_dot_query__pb2.QueryUserPathwayStakeRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryUserPathwayStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetUserReward',
            neurion_dot_ganglion_dot_query__pb2.QueryGetUserRewardRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetUserRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetProtocolFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetProtocolFee',
            neurion_dot_ganglion_dot_query__pb2.QueryGetProtocolFeeRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetProtocolFeeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PathwaysUsingIon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/PathwaysUsingIon',
            neurion_dot_ganglion_dot_query__pb2.QueryPathwaysUsingIonRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryPathwaysUsingIonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def IonsByReports(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/IonsByReports',
            neurion_dot_ganglion_dot_query__pb2.QueryIonsByReportsRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryIonsByReportsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllPathways(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/ListAllPathways',
            neurion_dot_ganglion_dot_query__pb2.QueryListAllPathwaysRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryListAllPathwaysResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetReward',
            neurion_dot_ganglion_dot_query__pb2.QueryGetRewardRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStake(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetStake',
            neurion_dot_ganglion_dot_query__pb2.QueryGetStakeRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetStakeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIon(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetIon',
            neurion_dot_ganglion_dot_query__pb2.QueryGetIonRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetIonResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetPathwayUnstakeInitiatedUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetPathwayUnstakeInitiatedUsers',
            neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayUnstakeInitiatedUsersRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetPathwayUnstakeInitiatedUsersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetStakerReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetStakerReward',
            neurion_dot_ganglion_dot_query__pb2.QueryGetStakerRewardRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetStakerRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAvailableIons(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetAvailableIons',
            neurion_dot_ganglion_dot_query__pb2.QueryGetAvailableIonsRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetAvailableIonsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateIonChain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/ValidateIonChain',
            neurion_dot_ganglion_dot_query__pb2.QueryValidateIonChainRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryValidateIonChainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetAllowedIps(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/neurion.ganglion.Query/GetAllowedIps',
            neurion_dot_ganglion_dot_query__pb2.QueryGetAllowedIpsRequest.SerializeToString,
            neurion_dot_ganglion_dot_query__pb2.QueryGetAllowedIpsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from gogoproto import gogo_pb2 as _gogo_pb2
from cometbft.types.v1beta1 import types_pb2 as _types_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CanonicalBlockID(_message.Message):
    __slots__ = ("hash", "part_set_header")
    HASH_FIELD_NUMBER: _ClassVar[int]
    PART_SET_HEADER_FIELD_NUMBER: _ClassVar[int]
    hash: bytes
    part_set_header: CanonicalPartSetHeader
    def __init__(self, hash: _Optional[bytes] = ..., part_set_header: _Optional[_Union[CanonicalPartSetHeader, _Mapping]] = ...) -> None: ...

class CanonicalPartSetHeader(_message.Message):
    __slots__ = ("total", "hash")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    HASH_FIELD_NUMBER: _ClassVar[int]
    total: int
    hash: bytes
    def __init__(self, total: _Optional[int] = ..., hash: _Optional[bytes] = ...) -> None: ...

class CanonicalProposal(_message.Message):
    __slots__ = ("type", "height", "round", "pol_round", "block_id", "timestamp", "chain_id")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    POL_ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    type: _types_pb2.SignedMsgType
    height: int
    round: int
    pol_round: int
    block_id: CanonicalBlockID
    timestamp: _timestamp_pb2.Timestamp
    chain_id: str
    def __init__(self, type: _Optional[_Union[_types_pb2.SignedMsgType, str]] = ..., height: _Optional[int] = ..., round: _Optional[int] = ..., pol_round: _Optional[int] = ..., block_id: _Optional[_Union[CanonicalBlockID, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., chain_id: _Optional[str] = ...) -> None: ...

class CanonicalVote(_message.Message):
    __slots__ = ("type", "height", "round", "block_id", "timestamp", "chain_id")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    BLOCK_ID_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    type: _types_pb2.SignedMsgType
    height: int
    round: int
    block_id: CanonicalBlockID
    timestamp: _timestamp_pb2.Timestamp
    chain_id: str
    def __init__(self, type: _Optional[_Union[_types_pb2.SignedMsgType, str]] = ..., height: _Optional[int] = ..., round: _Optional[int] = ..., block_id: _Optional[_Union[CanonicalBlockID, _Mapping]] = ..., timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., chain_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ibc/core/client/v1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'ibc/core/client/v1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bibc/core/client/v1/tx.proto\x12\x12ibc.core.client.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xbb\x01\n\x0fMsgCreateClient\x12\x43\n\x0c\x63lient_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\x12I\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\"\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x19\n\x17MsgCreateClientResponse\"z\n\x0fMsgUpdateClient\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12$\n\x06header\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x19\n\x17MsgUpdateClientResponse\"\xf5\x02\n\x10MsgUpgradeClient\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x43\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\x12I\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1a\xf2\xde\x1f\x16yaml:\"consensus_state\"\x12=\n\x14proof_upgrade_client\x18\x04 \x01(\x0c\x42\x1f\xf2\xde\x1f\x1byaml:\"proof_upgrade_client\"\x12O\n\x1dproof_upgrade_consensus_state\x18\x05 \x01(\x0c\x42(\xf2\xde\x1f$yaml:\"proof_upgrade_consensus_state\"\x12\x0e\n\x06signer\x18\x06 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1a\n\x18MsgUpgradeClientResponse\"\x86\x01\n\x15MsgSubmitMisbehaviour\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12*\n\x0cmisbehaviour\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06signer\x18\x03 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1f\n\x1dMsgSubmitMisbehaviourResponse2\xa2\x03\n\x03Msg\x12`\n\x0c\x43reateClient\x12#.ibc.core.client.v1.MsgCreateClient\x1a+.ibc.core.client.v1.MsgCreateClientResponse\x12`\n\x0cUpdateClient\x12#.ibc.core.client.v1.MsgUpdateClient\x1a+.ibc.core.client.v1.MsgUpdateClientResponse\x12\x63\n\rUpgradeClient\x12$.ibc.core.client.v1.MsgUpgradeClient\x1a,.ibc.core.client.v1.MsgUpgradeClientResponse\x12r\n\x12SubmitMisbehaviour\x12).ibc.core.client.v1.MsgSubmitMisbehaviour\x1a\x31.ibc.core.client.v1.MsgSubmitMisbehaviourResponseB:Z8github.com/cosmos/ibc-go/v2/modules/core/02-client/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.client.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/cosmos/ibc-go/v2/modules/core/02-client/types'
  _globals['_MSGCREATECLIENT'].fields_by_name['client_state']._loaded_options = None
  _globals['_MSGCREATECLIENT'].fields_by_name['client_state']._serialized_options = b'\362\336\037\023yaml:\"client_state\"'
  _globals['_MSGCREATECLIENT'].fields_by_name['consensus_state']._loaded_options = None
  _globals['_MSGCREATECLIENT'].fields_by_name['consensus_state']._serialized_options = b'\362\336\037\026yaml:\"consensus_state\"'
  _globals['_MSGCREATECLIENT']._loaded_options = None
  _globals['_MSGCREATECLIENT']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGUPDATECLIENT'].fields_by_name['client_id']._loaded_options = None
  _globals['_MSGUPDATECLIENT'].fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _globals['_MSGUPDATECLIENT']._loaded_options = None
  _globals['_MSGUPDATECLIENT']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGUPGRADECLIENT'].fields_by_name['client_id']._loaded_options = None
  _globals['_MSGUPGRADECLIENT'].fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _globals['_MSGUPGRADECLIENT'].fields_by_name['client_state']._loaded_options = None
  _globals['_MSGUPGRADECLIENT'].fields_by_name['client_state']._serialized_options = b'\362\336\037\023yaml:\"client_state\"'
  _globals['_MSGUPGRADECLIENT'].fields_by_name['consensus_state']._loaded_options = None
  _globals['_MSGUPGRADECLIENT'].fields_by_name['consensus_state']._serialized_options = b'\362\336\037\026yaml:\"consensus_state\"'
  _globals['_MSGUPGRADECLIENT'].fields_by_name['proof_upgrade_client']._loaded_options = None
  _globals['_MSGUPGRADECLIENT'].fields_by_name['proof_upgrade_client']._serialized_options = b'\362\336\037\033yaml:\"proof_upgrade_client\"'
  _globals['_MSGUPGRADECLIENT'].fields_by_name['proof_upgrade_consensus_state']._loaded_options = None
  _globals['_MSGUPGRADECLIENT'].fields_by_name['proof_upgrade_consensus_state']._serialized_options = b'\362\336\037$yaml:\"proof_upgrade_consensus_state\"'
  _globals['_MSGUPGRADECLIENT']._loaded_options = None
  _globals['_MSGUPGRADECLIENT']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGSUBMITMISBEHAVIOUR'].fields_by_name['client_id']._loaded_options = None
  _globals['_MSGSUBMITMISBEHAVIOUR'].fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _globals['_MSGSUBMITMISBEHAVIOUR']._loaded_options = None
  _globals['_MSGSUBMITMISBEHAVIOUR']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCREATECLIENT']._serialized_start=101
  _globals['_MSGCREATECLIENT']._serialized_end=288
  _globals['_MSGCREATECLIENTRESPONSE']._serialized_start=290
  _globals['_MSGCREATECLIENTRESPONSE']._serialized_end=315
  _globals['_MSGUPDATECLIENT']._serialized_start=317
  _globals['_MSGUPDATECLIENT']._serialized_end=439
  _globals['_MSGUPDATECLIENTRESPONSE']._serialized_start=441
  _globals['_MSGUPDATECLIENTRESPONSE']._serialized_end=466
  _globals['_MSGUPGRADECLIENT']._serialized_start=469
  _globals['_MSGUPGRADECLIENT']._serialized_end=842
  _globals['_MSGUPGRADECLIENTRESPONSE']._serialized_start=844
  _globals['_MSGUPGRADECLIENTRESPONSE']._serialized_end=870
  _globals['_MSGSUBMITMISBEHAVIOUR']._serialized_start=873
  _globals['_MSGSUBMITMISBEHAVIOUR']._serialized_end=1007
  _globals['_MSGSUBMITMISBEHAVIOURRESPONSE']._serialized_start=1009
  _globals['_MSGSUBMITMISBEHAVIOURRESPONSE']._serialized_end=1040
  _globals['_MSG']._serialized_start=1043
  _globals['_MSG']._serialized_end=1461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/slashing/v1beta1/tx.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/slashing/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/slashing/v1beta1/tx.proto\x12\x17\x63osmos.slashing.v1beta1\x1a\x14gogoproto/gogo.proto\"L\n\tMsgUnjail\x12\x35\n\x0evalidator_addr\x18\x01 \x01(\tB\x1d\xea\xde\x1f\x07\x61\x64\x64ress\xf2\xde\x1f\x0eyaml:\"address\":\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x01\"\x13\n\x11MsgUnjailResponse2_\n\x03Msg\x12X\n\x06Unjail\x12\".cosmos.slashing.v1beta1.MsgUnjail\x1a*.cosmos.slashing.v1beta1.MsgUnjailResponseB3Z-github.com/cosmos/cosmos-sdk/x/slashing/types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.slashing.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/x/slashing/types\250\342\036\001'
  _globals['_MSGUNJAIL'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_MSGUNJAIL'].fields_by_name['validator_addr']._serialized_options = b'\352\336\037\007address\362\336\037\016yaml:\"address\"'
  _globals['_MSGUNJAIL']._loaded_options = None
  _globals['_MSGUNJAIL']._serialized_options = b'\210\240\037\000\230\240\037\001'
  _globals['_MSGUNJAIL']._serialized_start=83
  _globals['_MSGUNJAIL']._serialized_end=159
  _globals['_MSGUNJAILRESPONSE']._serialized_start=161
  _globals['_MSGUNJAILRESPONSE']._serialized_end=180
  _globals['_MSG']._serialized_start=182
  _globals['_MSG']._serialized_end=277
# @@protoc_insertion_point(module_scope)



from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos_proto import cosmos_pb2 as _cosmos_pb2
from amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ValidationTask(_message.Message):
    __slots__ = ("id", "task_id", "proposed_model_id", "model", "metainfo", "validator", "created_timestamp", "score", "score_timestamp", "testset", "round")
    ID_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    PROPOSED_MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    METAINFO_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    CREATED_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    SCORE_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    TESTSET_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    id: int
    task_id: int
    proposed_model_id: int
    model: str
    metainfo: str
    validator: str
    created_timestamp: int
    score: str
    score_timestamp: int
    testset: str
    round: int
    def __init__(self, id: _Optional[int] = ..., task_id: _Optional[int] = ..., proposed_model_id: _Optional[int] = ..., model: _Optional[str] = ..., metainfo: _Optional[str] = ..., validator: _Optional[str] = ..., created_timestamp: _Optional[int] = ..., score: _Optional[str] = ..., score_timestamp: _Optional[int] = ..., testset: _Optional[str] = ..., round: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/app/runtime/v2/module.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'cosmos/app/runtime/v2/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/app/runtime/v2/module.proto\x12\x15\x63osmos.app.runtime.v2\x1a cosmos/app/v1alpha1/module.proto\"\x88\x03\n\x06Module\x12\x10\n\x08\x61pp_name\x18\x01 \x01(\t\x12\x14\n\x0cpre_blockers\x18\x02 \x03(\t\x12\x16\n\x0e\x62\x65gin_blockers\x18\x03 \x03(\t\x12\x14\n\x0c\x65nd_blockers\x18\x04 \x03(\t\x12\x15\n\rtx_validators\x18\x05 \x03(\t\x12\x14\n\x0cinit_genesis\x18\x06 \x03(\t\x12\x16\n\x0e\x65xport_genesis\x18\x07 \x03(\t\x12\x18\n\x10order_migrations\x18\x08 \x03(\t\x12\x34\n\ngas_config\x18\t \x01(\x0b\x32 .cosmos.app.runtime.v2.GasConfig\x12\x42\n\x13override_store_keys\x18\n \x03(\x0b\x32%.cosmos.app.runtime.v2.StoreKeyConfig\x12\x17\n\x0fskip_store_keys\x18\x0b \x03(\t:6\xba\xc0\x96\xda\x01\x30\n\x17\x63osmossdk.io/runtime/v2\x12\x15\n\x13\x63osmos.app.v1alpha1\"a\n\tGasConfig\x12\x1d\n\x15validate_tx_gas_limit\x18\x01 \x01(\x04\x12\x17\n\x0fquery_gas_limit\x18\x02 \x01(\x04\x12\x1c\n\x14simulation_gas_limit\x18\x03 \x01(\x04\";\n\x0eStoreKeyConfig\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\x12\x14\n\x0ckv_store_key\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.app.runtime.v2.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\0010\n\027cosmossdk.io/runtime/v2\022\025\n\023cosmos.app.v1alpha1'
  _globals['_MODULE']._serialized_start=96
  _globals['_MODULE']._serialized_end=488
  _globals['_GASCONFIG']._serialized_start=490
  _globals['_GASCONFIG']._serialized_end=587
  _globals['_STOREKEYCONFIG']._serialized_start=589
  _globals['_STOREKEYCONFIG']._serialized_end=648
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/blockchain/types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'tendermint/blockchain/types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!tendermint/blockchain/types.proto\x12\x15tendermint.blockchain\x1a\x1ctendermint/types/block.proto\"\x1e\n\x0c\x42lockRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"!\n\x0fNoBlockResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\"7\n\rBlockResponse\x12&\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x17.tendermint.types.Block\"\x0f\n\rStatusRequest\".\n\x0eStatusResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x03\"\xd5\x02\n\x07Message\x12<\n\rblock_request\x18\x01 \x01(\x0b\x32#.tendermint.blockchain.BlockRequestH\x00\x12\x43\n\x11no_block_response\x18\x02 \x01(\x0b\x32&.tendermint.blockchain.NoBlockResponseH\x00\x12>\n\x0e\x62lock_response\x18\x03 \x01(\x0b\x32$.tendermint.blockchain.BlockResponseH\x00\x12>\n\x0estatus_request\x18\x04 \x01(\x0b\x32$.tendermint.blockchain.StatusRequestH\x00\x12@\n\x0fstatus_response\x18\x05 \x01(\x0b\x32%.tendermint.blockchain.StatusResponseH\x00\x42\x05\n\x03sumB>Z<github.com/tendermint/tendermint/proto/tendermint/blockchainb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.blockchain.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/tendermint/tendermint/proto/tendermint/blockchain'
  _globals['_BLOCKREQUEST']._serialized_start=90
  _globals['_BLOCKREQUEST']._serialized_end=120
  _globals['_NOBLOCKRESPONSE']._serialized_start=122
  _globals['_NOBLOCKRESPONSE']._serialized_end=155
  _globals['_BLOCKRESPONSE']._serialized_start=157
  _globals['_BLOCKRESPONSE']._serialized_end=212
  _globals['_STATUSREQUEST']._serialized_start=214
  _globals['_STATUSREQUEST']._serialized_end=229
  _globals['_STATUSRESPONSE']._serialized_start=231
  _globals['_STATUSRESPONSE']._serialized_end=277
  _globals['_MESSAGE']._serialized_start=280
  _globals['_MESSAGE']._serialized_end=621
# @@protoc_insertion_point(module_scope)
